@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::Util::Callback;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my %callback;
 
@@ -28,27 +28,37 @@ sub register {
 	foreach (@$name) {
 
 	  # Get callback
-	  if (my $cb = delete $param->{$_}) {
+	  my $cb = delete $param->{$_};
+
+	  # Get callback
+	  if ($cb) {
 
 	    # Establish callback
 	    if (ref $cb && ref $cb eq 'CODE') {
 	      $mojo->callback($_, $cb, $flag);
 	    };
+	  }
+
+	  elsif ($flag && $flag eq '-once') {
+
+	    # Only allow the next establishement
+	    $callback{$_} = [undef, 1];
 	  };
 	};
 
 	# Everything went fine
 	return 1;
-      };
+      }
 
       # Establish callback
-      if (ref $_[0] && ref $_[0] eq 'CODE') {
+      elsif (ref $_[0] && ref $_[0] eq 'CODE') {
 	my $cb = shift;
 	my $once = $_[0] && $_[0] eq '-once' ? 1 : 0;
 
-
 	# Callback exists
-	if (exists $callback{$name} && $callback{$name}->[1]) {
+	if (exists $callback{$name} &&   # Callback exists
+	      $callback{$name}->[0] &&   # Callback is defined
+		$callback{$name}->[1]) { # Callback is -once
 	  $mojo->log->debug(
 	    qq{No allowance to redefine callback "$name"}
 	  );
@@ -58,14 +68,22 @@ sub register {
 	};
 
 	# Establish callback
-	$callback{$name} = [$cb, $once];
+	for ($callback{$name} //= []) {
+	  $_->[0] = $cb;
+	  $_->[1] ||= $once;
+	};
+
+	return 1;
       }
 
       # Release callback
       else {
 
 	# Release existing callback
-	return $callback{$name}->[0]->($c, @_) if exists $callback{$name};
+	my $cb;
+	if (exists $callback{$name} && ($cb = $callback{$name}->[0])) {
+	  return $cb->($c, @_) ;
+	};
 
 	# Return nothing
 	return;
@@ -84,7 +102,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Util::Callback - Reverse helpers for Mojolicious
+Mojolicious::Plugin::Util::Callback - Reverse Helpers for Mojolicious
 
 
 =head1 SYNOPSIS
@@ -204,6 +222,16 @@ be deleted from the hash, while the rest will stay intact.
   # In controller, app or template
   my $profile = $c->fetch_profile('Akron');
 
+If the callback to be defined by parameters is given the C<-once>
+flag, this will be saved as a signature. The next established
+callback can't be overwritten, no matter if it is established
+without a C<-once> flag.
+
+
+=head1 DEPENDENCIES
+
+L<Mojolicious> (best with SSL support).
+
 
 =head1 AVAILABILITY
 
